
From: Roland Dreier <roland@topspin.com>

The last parameter of proc_symlink is usually a "const char *", but the
stub in <linux/proc_fs.h> for CONFIG_PROC_FS=n omits the const and makes
its last parameter a "char *".  This causes a warning about discarding
qualifiers for any code that passes something const for that last
parameter.

This patch fixes that up and also, for neatness's sake, makes the stub for
create_proc_read_entry() match the usual prototype more exactly (use
read_proc_t rather than the underlying function pointer type).

Signed-off-by: Roland Dreier <roland@topspin.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/linux/proc_fs.h |    5 ++---
 1 files changed, 2 insertions(+), 3 deletions(-)

diff -puN include/linux/proc_fs.h~fix-proc_symlink-warning-with-config_proc_fs=n include/linux/proc_fs.h
--- 25/include/linux/proc_fs.h~fix-proc_symlink-warning-with-config_proc_fs=n	2004-08-31 20:34:06.567558456 -0700
+++ 25-akpm/include/linux/proc_fs.h	2004-08-31 20:34:06.570558000 -0700
@@ -206,14 +206,13 @@ static inline struct proc_dir_entry *cre
 #define remove_proc_entry(name, parent) do {} while (0)
 
 static inline struct proc_dir_entry *proc_symlink(const char *name,
-		struct proc_dir_entry *parent,char *dest) {return NULL;}
+		struct proc_dir_entry *parent,const char *dest) {return NULL;}
 static inline struct proc_dir_entry *proc_mkdir(const char *name,
 	struct proc_dir_entry *parent) {return NULL;}
 
 static inline struct proc_dir_entry *create_proc_read_entry(const char *name,
 	mode_t mode, struct proc_dir_entry *base, 
-	int (*read_proc)(char *, char **, off_t, int, int *, void *),
-	void * data) { return NULL; }
+	read_proc_t *read_proc, void * data) { return NULL; }
 static inline struct proc_dir_entry *create_proc_info_entry(const char *name,
 	mode_t mode, struct proc_dir_entry *base, get_info_t *get_info)
 	{ return NULL; }
_
